@@ -1,5 +1,5 @@
-from hestia_earth.earth_engine.utils import get_required_param, get_param
-from hestia_earth.earth_engine.gee_utils import load_geometry, is_below_max_size, MAX_AREA_SIZE
+from hestia_earth.earth_engine.utils import get_required_param
+from hestia_earth.earth_engine.gee_utils import load_geometry, area_km2
 from .utils import load
 
 GEOMETRY_BY_TYPE = {
@@ -27,9 +27,9 @@ def _get_geometry(data: dict):
     return geometry.centroid() if use_centroid else geometry
 
 
-def should_run(data: dict):
-    max_area = float(get_param(data, 'max_area', MAX_AREA_SIZE))
-    return is_below_max_size(_get_geometry(data), max_area)
+def get_size_km2(data: dict):
+    boundary = data.get('boundary', data)
+    return area_km2(load_geometry(boundary)).getInfo()
 
 
 def run(data: dict):
